==> xwidgetsbase-10.7.9%2B6.tar.gz: lib/XApp/XfxArea.dart <==
part of xwidgetbase;
// import 'package:flutter/material.dart';
// import 'package:xtoolspackage/xtoolspackage.dart';
// import 'package:xwidgetsbase/XStylesBase.dart';
// import 'package:xwidgetsbase/xWidgetsBase.dart';

class XArea {
  String key_Area;
  int idx_Area;
  String? label_Area;
  IconData? icon_Area;
  Widget? widget_Area;
  Color? color_Area;
  Color? color_AppBar;
  XArea(
    this.key_Area,
    this.idx_Area,
    this.widget_Area, {
    this.label_Area,
    this.icon_Area,
    this.color_Area,
    this.color_AppBar,
  });
}

class XfxArea extends StatefulWidget {
  XfxArea({
    this.title = "",
    this.tapOnTab,
    this.backGroundColor,
    this.title_Color,
    this.title_Visible = true,
    this.children,
    this.numberOfTabs,
    this.tabs,
    this.bottomBar_Visible = true,
    this.isScrollableTabs = false,
    this.bottomBar_OnTap,
    this.bottomBar_CurrentIdx,
    this.tabs_BackGroundColor,
    this.tabController,
    this.margin_Horizontal,
    this.title_Style,
    this.sch_Decoration,
    this.borderVisible,
  }) : super();
  final String title;
  final Function(int)? tapOnTab;
  final bool title_Visible;
  final Color? title_Color;
  final TabController? tabController;
  final List<Widget>? children;
  final bool? borderVisible;
  final Color? backGroundColor;
  final int? numberOfTabs;
  final bool? bottomBar_Visible;
  final List<XTabItem>? tabs;
  final bool? isScrollableTabs;
  final Decoration? sch_Decoration;
  final int? bottomBar_CurrentIdx;
  final Function(int)? bottomBar_OnTap;
  final double? margin_Horizontal;
  final Color? tabs_BackGroundColor;
  final TextStyle? title_Style;
  @override
  _XfxAreaState createState() => _XfxAreaState();
}

class _XfxAreaState extends State<XfxArea> {
  // late TabController tabController;

  @override
  void initState() {
    // tabController = TabController(length: widget.tabs!.length, vsync: this);
    super.initState();
  }

  tabPagesSch(
    IconData icon,
    String? label,
    XTabItem? item, {
    Color? colorTab_Active,
    Color? colorTab,
    TextStyle? labelStyle_ALL,
    Color? labelColor_ALL,
    Color? labelColor_Active,
    Color? labelColor_Disabled,
    Color? iconsColor_ALL,
    Color? iconsColor_Active,
    Color? iconsColor_Disabled,
  }) {
    Color getTabItem_IconColor(XTabItem item, int idx) {
      if (item.idx == idx) {
        return item.iconColor_Active ?? iconsColor_Active ?? iconsColor_ALL ?? XColors.foregroundDark;
      } else {
        return item.iconColor_Disabled ?? iconsColor_Disabled ?? iconsColor_ALL ?? XColors.foregroundLight;
      }
    }

    Color getTabItem_LabelColor(XTabItem item, int idx) {
      if (item.idx == idx) {
        return item.labelColor_Active ?? labelColor_Active ?? iconsColor_Active ?? labelColor_ALL ?? iconsColor_ALL ?? XColors.foregroundDark;
      } else {
        return item.labelColor_Disabled ?? labelColor_Disabled ?? labelColor_ALL ?? iconsColor_Disabled ?? iconsColor_ALL ?? XColors.foregroundLight;
      }
    }

    Color getTabItem_BackgroundColor(XTabItem item, int idx) {
      if (item.idx == idx) {
        return item.color_backGroundTab_Activate ?? Colors.grey[900]!;
      } else {
        return item.color_backGroundTab ?? Colors.grey[900]!;
      }
    }

    return Container(
        padding: EdgeInsets.symmetric(horizontal: 10),
        color: getTabItem_BackgroundColor(item!, widget.tabController!.index),
        child: Tab(
            height: 50,
            // icon: ,
            child: Row(
              children: [
                icon != null ? Expanded(child: FittedBox(fit: BoxFit.scaleDown, child: Icon(icon, size: 35, color: iconsColor_ALL ?? getTabItem_IconColor(item, widget.tabController!.index)))) : Container(),
                SizedBox(width: 10),
                Expanded(
                    child: Text(
                  item.label,
                  style: labelStyle_ALL ?? XStyles.xStyTextForLabel(getTabItem_LabelColor(item, widget.tabController!.index)),
                  overflow: TextOverflow.ellipsis,
                ))
              ],
            )));
  }

  @override
  Widget build(BuildContext context) {
    // tabController = TabController(length: widget.tabs!.length, vsync: this);
    // tabController.addListener(() {
    //   setState(() {});
    // });

    return DefaultTabController(
        length: widget.tabs!.length,
        child: Container(
          decoration: widget.sch_Decoration,
          margin: EdgeInsets.symmetric(horizontal: widget.margin_Horizontal ?? 15),
          child: Column(children: [
            widget.title_Visible == true ? SizedBox(height: 10) : SizedBox(height: 0),
            widget.title_Visible == true
                ? Row(
                    children: [
                      Expanded(child: XContainerWithLabel(widget.title, height: 30, color: XColors.backGroundTitleContainerForScheda_MAIN, textStyle: widget.title_Style ?? XStyles.xStyTextForTextBase(widget.title_Color ?? Colors.white))),
                    ],
                  )
                : Container(),
            widget.title_Visible == true ? SizedBox(height: 3) : SizedBox(height: 0),
            TabBar(
              automaticIndicatorColorAdjustment: false,
              controller: widget.tabController,
              indicator: BoxDecoration(color: Colors.transparent),
              isScrollable: widget.isScrollableTabs!,
              unselectedLabelColor: Colors.white,
              // indicatorColor: Colors.white,
              tabs: widget.tabs!
                  .map((x) => tabPagesSch(
                        x.icon!,
                        x.caption,
                        x,
                        iconsColor_Active: x.iconColor_Active,
                        iconsColor_Disabled: Colors.white,
                        labelColor_Active: x.iconColor_Active,
                      ) as Widget)
                  .toList(),
              onTap: (idx) {
                FocusScopeNode currentFocus = FocusScope.of(context);
                if (!currentFocus.hasPrimaryFocus && currentFocus.focusedChild != null) {
                  FocusManager.instance.primaryFocus?.unfocus();
                }
                widget.tapOnTab!(idx);
              },
            ),
            Expanded(
                child: Container(
                    decoration: (widget.borderVisible ?? false) //
                        ? BoxDecoration(color: XColors.backgroundDark, border: Border.all(color: widget.tabs_BackGroundColor ?? Colors.transparent, width: 2)) //
                        : null,
                    child: TabBarView(
                      children: widget.children!,
                      controller: widget.tabController,
                    ))),
            SizedBox(height: 5),
          ]),
        ));
  }
}

==> xwidgetsbase-10.8.8%2B6.tar.gz: lib/XApp/XfxArea.dart <==
part of xwidgetbase;
// import 'package:flutter/material.dart';
// import 'package:xtoolspackage/xtoolspackage.dart';
// import 'package:xwidgetsbase/XStylesBase.dart';
// import 'package:xwidgetsbase/xWidgetsBase.dart';

class XArea {
  String key_Area;
  int idx_Area;
  String? label_Area;
  IconData? icon_Area;
  Uint8List? imageIcon_Area;
  Widget? widget_Area;
  Color? color_Area;
  Color? color_AppBar;
  XArea(
    this.key_Area,
    this.idx_Area,
    this.widget_Area, {
    this.label_Area,
    this.icon_Area,
    this.imageIcon_Area,
    this.color_Area,
    this.color_AppBar,
  });
}

class XfxArea extends StatefulWidget {
  XfxArea({
    this.title = "",
    this.tapOnTab,
    this.backGroundColor,
    this.title_Color,
    this.title_Visible = true,
    this.children,
    this.numberOfTabs,
    this.tabs,
    this.bottomBar_Visible = true,
    this.isScrollableTabs = false,
    this.bottomBar_OnTap,
    this.bottomBar_CurrentIdx,
    this.tabs_BackGroundColor,
    this.tabController,
    this.margin_Horizontal,
    this.title_Style,
    this.sch_Decoration,
    this.borderVisible,
    this.xApp,
  }) : super();
  final String title;
  final Function(int)? tapOnTab;
  final bool title_Visible;
  final Color? title_Color;
  XAppDataBase? xApp;
  TabController? tabController;
  final List<Widget>? children;
  final bool? borderVisible;
  final Color? backGroundColor;
  final int? numberOfTabs;
  final bool? bottomBar_Visible;
  final List<XTabItem>? tabs;
  final bool? isScrollableTabs;
  final Decoration? sch_Decoration;
  final int? bottomBar_CurrentIdx;
  final Function(int)? bottomBar_OnTap;
  final double? margin_Horizontal;
  final Color? tabs_BackGroundColor;
  final TextStyle? title_Style;
  @override
  _XfxAreaState createState() => _XfxAreaState();
}

class _XfxAreaState extends State<XfxArea> {
  // late TabController tabController;

  @override
  void initState() {
    // widget.tabController = TabController(length: widget.tabs!.length, vsync: this);
    super.initState();
  }

  tabPagesSch(
    String? label,
    XTabItem? item, {
    IconData? icon,
    Uint8List? image_Icon_BTN,
    Color? colorTab_Active,
    Color? colorTab,
    TextStyle? labelStyle_ALL,
    Color? labelColor_ALL,
    Color? labelColor_Active,
    Color? labelColor_Disabled,
    Color? iconsColor_ALL,
    Color? iconsColor_Active,
    Color? iconsColor_Disabled,
  }) {
    Color getTabItem_IconColor(XTabItem item, int idx) {
      if (item.idx == idx) {
        return item.iconColor_Active ?? iconsColor_Active ?? iconsColor_ALL ?? XColors.foregroundDark;
      } else {
        return item.iconColor_Disabled ?? iconsColor_Disabled ?? iconsColor_ALL ?? XColors.foregroundLight;
      }
    }

    Color getTabItem_LabelColor(XTabItem item, int idx) {
      if (item.idx == idx) {
        return item.labelColor_Active ?? labelColor_Active ?? iconsColor_Active ?? labelColor_ALL ?? iconsColor_ALL ?? XColors.foregroundDark;
      } else {
        return item.labelColor_Disabled ?? labelColor_Disabled ?? labelColor_ALL ?? iconsColor_Disabled ?? iconsColor_ALL ?? XColors.foregroundLight;
      }
    }

    Color getTabItem_BackgroundColor(XTabItem item, int idx) {
      if (item.idx == idx) {
        return item.color_backGroundTab_Activate ?? Colors.grey[900]!;
      } else {
        return item.color_backGroundTab ?? Colors.grey[900]!;
      }
    }

    return Container(
        margin: EdgeInsets.symmetric(horizontal: 5),
        color: getTabItem_BackgroundColor(item!, widget.tabController!.index),
        child: Tab(
            height: 50,
            iconMargin: EdgeInsets.all(0),
            child: Row(
              children: [
                image_Icon_BTN != null
                    ? Image.memory(image_Icon_BTN, width: 40, height: 40)
                    : icon != null
                        ? Container(width: 40, height: 40, child: FittedBox(fit: BoxFit.scaleDown, child: Icon(icon, size: 35, color: iconsColor_ALL ?? getTabItem_IconColor(item, widget.tabController!.index))))
                        : Container(),
                SizedBox(width: 10),
                Expanded(
                    child: Text(
                  item.label,
                  style: labelStyle_ALL ?? XStyles.xStyTextForLabel(getTabItem_LabelColor(item, widget.tabController!.index)),
                  overflow: TextOverflow.ellipsis,
                )),
                Container(
                    height: 50,
                    alignment: Alignment.topCenter,
                    child: XBtnbase(
                        icon: Icons.close,
                        icon_Color: Colors.redAccent,
                        height: 40,
                        icon_WidthArea: 40,
                        width: 40,
                        icon_Size: 20,
                        onPressed: () {
                          setState(() {
                            widget.xApp!.li_XAree.removeWhere((element) => element.idx_Area == item.idx);
                            widget.tabs!.remove(item);
                            updateTabController();
                          });
                        })),
              ],
            )));
  }

  updateTabController() {
//    tabController = TabController(length: widget.li_XAree!.length, vsync: this);
    // widget.tabController = TabController(length: widget.xApp!.li_XAree.length, vsync: this);

    setState(() {
      print(widget.tabController!.index.toString());
      widget.tabController!.index = widget.xApp!.li_XAree.firstWhere((element) => element.key_Area == widget.xApp!.area_Active.key_Area).idx_Area;
      print(widget.tabController!.index.toString());
    });
  }

  @override
  Widget build(BuildContext context) {
    // tabController = TabController(length: widget.tabs!.length, vsync: this);
    // tabController.addListener(() {
    //   setState(() {});
    // });

    return DefaultTabController(
        length: widget.tabs!.length,
        child: Container(
          margin: EdgeInsets.symmetric(horizontal: widget.margin_Horizontal ?? 15),
          child: Column(children: [
            widget.title_Visible == true ? SizedBox(height: 10) : SizedBox(height: 0),
            widget.title_Visible == true
                ? Row(
                    children: [
                      Expanded(child: XContainerWithLabel(widget.title, height: 30, color: XColors.backGroundTitleContainerForScheda_MAIN, textStyle: widget.title_Style ?? XStyles.xStyTextForTextBase(widget.title_Color ?? Colors.white))),
                    ],
                  )
                : Container(
                    height: 0,
                    width: 0,
                  ),
            widget.title_Visible == true ? SizedBox(height: 3) : SizedBox(height: 0),
            TabBar(
              automaticIndicatorColorAdjustment: false,
              controller: widget.tabController,
              indicator: BoxDecoration(color: Colors.transparent),
              isScrollable: widget.isScrollableTabs!,
              unselectedLabelColor: Colors.white,
              indicatorPadding: EdgeInsets.all(0),
              labelPadding: EdgeInsets.all(0),
              padding: EdgeInsets.all(0),
              // indicatorColor: Colors.white,
              tabs: widget.tabs!
                  .map((x) => tabPagesSch(
                        x.caption,
                        x,
                        icon: x.icon,
                        image_Icon_BTN: x.image_Icon,
                        iconsColor_Active: x.iconColor_Active,
                        iconsColor_Disabled: Colors.white,
                        labelColor_Active: x.iconColor_Active,
                      ) as Widget)
                  .toList(),
              onTap: (idx) {
                FocusScopeNode currentFocus = FocusScope.of(context);
                if (!currentFocus.hasPrimaryFocus && currentFocus.focusedChild != null) {
                  FocusManager.instance.primaryFocus?.unfocus();
                }
                widget.tapOnTab!(idx);
              },
            ),
            Expanded(
                child: Container(
                    decoration: (widget.borderVisible ?? false) //
                        ? BoxDecoration(color: XColors.backgroundDark, border: Border.all(color: widget.tabs_BackGroundColor ?? Colors.transparent, width: 2)) //
                        : null,
                    child: TabBarView(
                      children: widget.children!,
                      controller: widget.tabController,
                    ))),
            SizedBox(height: 5),
          ]),
        ));
  }
}
